@@ -47,6 +47,8 @@ class OutputTrack:
         Dictionary that tells the BasicFX class what effects to use. Key being the function effect and the value (which is a another dictionary) being the parameters. Defaults to None. (Do not set a set_volume effect here. That is controlled by the `volume` parameter)
     `queue_maxsize` : int
         The maxsize parameter passed onto the queue.Queue of this track. Defaults to 50. You usually don't need to touch this.
+    `reserved` : bool
+        The mixer class has a property called `available_output_track` and it returns all output tracks that are not playing. You can set this parameter to True to tell the mixer that this track is always unavailable regardless of whether it is playing or not. Defaults to False.
     """
 
     def __init__(self, name: str, **kwargs) -> None:
@@ -55,6 +57,7 @@ class OutputTrack:
         self.sounddevice_parameters = kwargs.get("sounddevice_parameters", {})
         self.conversion_path = kwargs.get("conversion_path")
         self.apply_basic_fx = kwargs.get("apply_basic_fx", True)
+        self.reserved = kwargs.get("reserved", False)
         self.__kwargs = kwargs
 
         # Main queue, this is where all data that
